# DisHook
Python x ChatGPT script. Generates random Discord Nitro codes and test their validity by sending requests to the Discord server. If the generated code is valid, the script will send the code to the specified Discord webhook.
<br><center><img src="https://github.com/im-hanzou/DisHook/blob/main/dishook.png" width="600"></center><br>
This code is inspired from <a href="https://www.youtube.com/watch?v=-bnVGH62Yho&ab_channel=NoTextToSpeech">YouTube/NoTextToSpeech</a> and featuring ChatGPT ( im-lazy )<br>
Thanks to <a href="https://github.com/rikurunico">rikurunico</a> for helping fix the code!
# Usage
### Installation and Running:
- Download or <code>git clone https://github.com/im-hanzou/DisHook.git</code> from this repository.
- Install modules by running the following command: <code>pip install -r requirements.txt</code>
- Run the script using the following command: <code>python dishook.py</code>
### Discord webhook URL retrieval
Retreiving discord webhook URL: <a href="https://support.discord.com/hc/en-us/articles/228383668-Intro-to-Webhooks">Discord Webhook<a>
## Disclaimer
This script was created for educational purposes only. Misuse or inappropriate use of this script is the user's responsibility. The author is not responsible for any negative consequences resulting from inappropriate use of this script. Use it wisely.
# Note
Update: add mode generator only and checker only!<br>
Proxied version will be updated soon! <3
# THIS CODE IS FREE! DON'T SELL THIS CODE!
